@@ -10,7 +10,7 @@
     Copyright (c) 2005 Etersoft
     Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
 
-    $Id: get_charset.c,v 1.19 2005/03/09 20:18:02 lav Exp $
+    $Id: get_charset.c,v 1.22 2005/07/21 18:29:47 vitlav Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -46,7 +46,7 @@
 #endif
 
 
-/* Internal: Helper for bsearch */
+/*! Internal: Helper for bsearch */
 static int charset_locale_cmp( const void *name, const void *entry )
 {
     const struct charsetrel_entry *rel = (const struct charsetrel_entry *)entry;
@@ -54,22 +54,22 @@ static int charset_locale_cmp( const void *name, const void *entry )
     return strcmp( (const char *)name, rel->locale );
 }
 
-/* Removes punctuation characters from charset name */
+/*! Removes punctuation characters from charset name */
 char *natspec_humble_charset( const char *charset)
 {
 	int i, j;
 	char *buf;
-	if (charset == NULL || charset[0] == '\0')
+	if (_n_isempty(charset))
 		return NULL;
 	/* Do not remove punctuation for ANSI encoding... */
-	if (strstr(charset,"ANSI_X3") != NULL)
+	if( strstr(charset,"ANSI_X3") )
 		return strdup(charset);
 	buf = alloca( strlen(charset) + 1 );
    	for (i = 0, j = 0; charset[i]; i++)
 	{
 		if (charset[i] == ':')
 			break;
-        if (_n_isalnum(charset[i]))
+		if (_n_isalnum(charset[i]))
 			buf[j++] = _n_toupper(charset[i]);
 	}
    	buf[j] = 0;
@@ -77,17 +77,14 @@ char *natspec_humble_charset( const char *charset)
 	return strdup(buf);
 }
 
-/* Returns current charset */
+/*! Returns current charset */
 const char *natspec_get_charset()
 {
 	const char *charset, *c;
 #if defined(HAVE_LANGINFO_CODESET)
 	charset = nl_langinfo(CODESET);
 	c = natspec_get_charset_by_charset(NATSPEC_UNIXCS, NATSPEC_UNIXCS, charset);
-	if (c == NULL)
-		return charset;
-	else
-		return c;
+	return c ?: charset;
 #else
 	#error "I have not an idea how do it"
 	/* recursive :) FIXME: I
@@ -96,8 +93,8 @@ const char *natspec_get_charset()
 }
 
 
-/*
-TODO:   ,   iconv
+/*!
+\todo   ,   iconv
 static char *normalize_charset(const char *charset)
 {
 	char *buf = malloc( strlen(charset) + 1 );
@@ -106,7 +103,7 @@ static char *normalize_charset(const char *charset)
 }
 */
 
-/* Returns charset for type OS. It never returns NULL,
+/*! Returns charset for type OS. It never returns NULL,
  * but current charset if other fails */
 static const char *get_cs_by_type(const int type,
 	const struct charsetrel_entry* entry)
@@ -116,20 +113,22 @@ static const char *get_cs_by_type(const int type,
 		switch(type)
 		{
 			case NATSPEC_WINCS:
-				return ( entry->win_cs ? entry->win_cs : "CP1252");
+				return entry->win_cs ?: "CP1252";
 			case NATSPEC_DOSCS:
-				return ( entry->dos_cs ? entry->dos_cs : "CP437");
+				return entry->dos_cs ?: "CP437";
 			case NATSPEC_MACCS:
-				return ( entry->mac_cs ? entry->mac_cs : "MAC");
+				return entry->mac_cs ?: "MAC";
 			case NATSPEC_UNIXCS:
-				return ( entry->unix_cs ? entry->unix_cs : "iso8859-1"); /* Really? */
+				return entry->unix_cs ?: "iso8859-1"; /* Really? */
 		}
 	/* fallback to locale charset */
 	return natspec_get_charset();
 }
 
 
-/* Internal: try search in charset_relation by encoding (troubles with the same enc)*/
+/*! Internal: try search in charset_relation by encoding
+    (Note: troubles with the same enc
+ */
 static const struct charsetrel_entry* get_entry_by_charset(const int bytype,
 	const char *charset)
 {
@@ -137,13 +136,13 @@ static const struct charsetrel_entry* get_entry_by_charset(const int bytype,
 	char *must_free = NULL;
 	DEBUG (printf("get_entry_by_charset charset=%s\n",charset));
 	/* If charset is NULL, use current charset */
-	if ((charset == NULL || charset[0] == '\0') && bytype == NATSPEC_UNIXCS)
+	if (_n_isempty(charset) && bytype == NATSPEC_UNIXCS)
 	{
 		/* Get charset for current locale */
 		charset = must_free = natspec_humble_charset(natspec_get_charset());
 		DEBUG (printf("2 cs=%s\n", charset));
 	}
-	if (charset != NULL && charset[0] != '\0')
+	if ( !_n_isempty(charset))
 	{
 		int i;
 		DEBUG (printf("Find with charset '%s'\n", charset));
@@ -151,7 +150,7 @@ static const struct charsetrel_entry* get_entry_by_charset(const int bytype,
 		for (i = 0; i< sizeof(charset_relation)/sizeof(charset_relation[0]); i++)
 			if (!strcmp (charset, get_cs_by_type(bytype,&charset_relation[i])))
 			{
-	    		entry = &charset_relation[i];
+				entry = &charset_relation[i];
 				break;
 			}
 	}
@@ -159,17 +158,16 @@ static const struct charsetrel_entry* get_entry_by_charset(const int bytype,
 	return entry;
 }
 
-/* Internal: Search _locale_ in list and returns entry pointer or NULL */
+/*! Internal: Search _locale_ in list and returns entry pointer or NULL */
 static const struct charsetrel_entry* get_entry_by_locale(const char *locale)
 {
-	const struct charsetrel_entry *entry = NULL;
+	const struct charsetrel_entry *entry;
 	char *replocale = _natspec_repack_locale(locale);
 
 	/* Search the same locale string in table. We are sure locale is repacked (normalized) */
-	if (replocale != NULL && replocale[0] != '\0')
-		entry = bsearch( replocale, charset_relation,
-	    	sizeof(charset_relation)/sizeof(charset_relation[0]),
-	        sizeof(charset_relation[0]), charset_locale_cmp );
+	if ( _n_isempty(replocale))
+		return NULL;
+	entry = _n_bsearch( replocale, charset_relation, charset_locale_cmp );
 	free (replocale);
 
 	DEBUG (if (!entry) printf ("Can't find the locale '%s'\n", locale));
@@ -177,7 +175,7 @@ static const struct charsetrel_entry* get_entry_by_locale(const char *locale)
 }
 
 
-/* Returns charset by locale for type */
+/*! Returns charset by locale for type */
 const char * natspec_get_charset_by_locale(const int type, const char *locale)
 {
 	char *must_free = NULL;
@@ -185,15 +183,22 @@ const char * natspec_get_charset_by_locale(const int type, const char *locale)
 	/* use system locale for NULL or user locale if empty */
 	if (locale == NULL)
 		locale = must_free = natspec_get_system_locale();
-	else
-	if (locale[0] == '\0')
+	else if (locale[0] == '\0')
 		locale = must_free = natspec_get_current_locale();
 	entry = get_entry_by_locale(locale);
 	free (must_free);
 	return get_cs_by_type(type, entry);
 }
 
-/* Returns static string by charset by bytype for type */
+/* Returns 0 if locale not in utf8 encoding */
+int natspec_locale_is_utf8(const char * locale)
+{
+	const char *charset = natspec_get_charset_by_locale(NATSPEC_UNIXCS, locale);
+	return !strcmp(charset, "UTF8");
+}
+
+
+/*! Returns static string by charset by bytype for type */
 const char * natspec_get_charset_by_charset(const int type,
 	const int bytype, const char *charset)
 {
