@@ -1,3 +1,4 @@
+//!!!!!!!  dlopen !!!!!!!
 /*
     src/natspec.c
 	
@@ -7,7 +8,7 @@
     Copyright (c) 2005 Etersoft
     Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
 
-    $Id: natspec.c,v 1.16 2005/04/09 21:58:00 lav Exp $
+    $Id: natspec.c,v 1.21 2005/07/21 22:23:08 vitlav Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -32,6 +33,7 @@
 #include <locale.h>
 
 #include "natspec_internal.h"
+#include "natspechi_internal.h"
 
 #ifdef HAVE_LIBPOPT
 #  include <popt.h>
@@ -45,7 +47,8 @@
 
 char *charset_type;
 char *locale, *transliterate;
-int version, verbose, fsenc, fcodepage, nls, flag_help, info, flag_locale;
+int version, verbose, fsenc, fcodepage, nls, flag_help, info;
+int flag_locale, utf8, country_id;
 
 #if defined HAVE_LIBPOPT
 poptContext context = NULL;
@@ -55,6 +58,10 @@ struct poptOption options[] =
      "print codepage", ""},
     {"fsenc", 'f', POPT_ARG_NONE,  &fsenc, 1,
      "print filesystem encoding", ""},
+	{"utf8", 0, POPT_ARG_NONE,  &utf8, 1,
+     "return 0 if locale is utfed", ""},
+	{"country-id", 0, POPT_ARG_NONE,  &country_id, 1,
+     "print country ID (international numbering)", ""},
     {"info", 'i', POPT_ARG_NONE,  &info, 0,
      "print overall encoding/charset info for your system", ""},
     {"transl", 'a', POPT_ARG_STRING,  &transliterate, 1,
@@ -101,23 +108,21 @@ static const char *get_charset(char *charset_type)
 
 int main(int argc, const char** argv)
 {
-
+	int is_utf8;
 #if defined HAVE_LIBPOPT
-  int rc = 0;
-  poptContext poptCtx;
-  poptCtx = poptGetContext("natspec", argc, (const char **)argv, options, 0);
-  poptSetOtherOptionHelp(poptCtx, "[OPTION...]");
-  while (rc >= 0) {
-    if((rc = poptGetNextOpt(poptCtx)) < -1) {
-      printf(("Error on option %s: %s.\nRun '%s --help' to see a full list of available command line options.\n"),
-	      poptBadOption(poptCtx, 0),
-	      poptStrerror(rc),
-	      argv[0]);
-      exit(1);
-    }
-    if(rc == 1) {
-    }
-  }
+	int rc = 0;
+	poptContext poptCtx;
+	poptCtx = poptGetContext("natspec", argc, (const char **)argv, options, 0);
+	poptSetOtherOptionHelp(poptCtx, "[OPTION...]");
+	while (rc >= 0) {
+		if((rc = poptGetNextOpt(poptCtx)) < -1) {
+			fprintf(stderr, "Error on option %s: %s.\nRun '%s --help' to see a full list of available command line options.\n",
+				poptBadOption(poptCtx, 0),
+				poptStrerror(rc),
+				argv[0]);
+			exit(1);
+		}
+	}
 /*
   { int flag_help=1;
   if (argv) {
@@ -129,19 +134,19 @@ int main(int argc, const char** argv)
 */	
     if(flag_help)
 	{
-	poptPrintHelp(poptCtx, stderr, 0);
+	poptPrintHelp(poptCtx, stdout, 0);
     exit(0);
 	}
 
 #else
-	printf("Compiled without popt. Exit\n");
+	fprintf(stderr, "Compiled without popt. Exit\n");
 	exit(1);
 #endif
 	if (argc == 1)
 		info = 1;
 	if (version || info)
 	{
-		printf("%s version %s\n",PACKAGE, PACKAGE_VERSION);
+		printf("%s, compiled %s\n",PACKAGE_STRING,__DATE__);
 		if (!info) exit(0);
 	}
 	if (transliterate)
@@ -183,14 +188,22 @@ int main(int argc, const char** argv)
 		if (verbose) puts("");
 		if (!info) exit(0);
 	}
-
+	if (country_id || info)
+	{
+		int id;
+		if (verbose) printf("Country ID (for DOS): ");
+//		id = natspec_get_country_id();
+		printf("%d", id);
+		if (verbose) puts("");
+		if (!info) exit(0);
+	}
 	if (fcodepage || info)
 	{
-		const char *buf;
+		int cp;
 		if (verbose) printf("Codepage of DOS: ");
-		buf = natspec_get_codepage_by_charset(
+		cp = natspec_get_codepage_by_charset(
 			natspec_get_charset_by_locale(NATSPEC_DOSCS, locale));
-		printf("%s",buf);
+		printf("%d", cp);
 		if (verbose) puts("");
 		if (!info) exit(0);
 	}
@@ -206,9 +219,13 @@ int main(int argc, const char** argv)
 		printf("\tnl_langinfo(CODESET): %s\n",nl_langinfo(CODESET));
 #endif
 		printf("\tnatspec_get_charset: %s\n",natspec_get_charset());
-		exit(0);
 	}
 	if (charset_type)
 		get_charset(charset_type);
+	is_utf8 = natspec_locale_is_utf8("");
+	if (verbose)
+		printf("Current locale is%sin UTF8 encoding\n",(is_utf8 ? " " : " NOT "));
+	if (utf8 && !info)
+		return is_utf8 ? 0 : 1;
 	return 0;
 }
